﻿namespace Xam_Graph
{
    #region

    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Windows;
    using System.Windows.Threading;

    using Infragistics.Windows.Chart;

    #endregion

    /// <summary>
    ///   Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        /// <summary>
        ///   This timer will execute every millisecond,
        ///   and the callback will run in the UI thread.
        /// </summary>
        private DispatcherTimer dTimer;

        private List<double> lstMethodExecutionTimes = new List<double>();

        private int nMethodExecutionCount;

        /// <summary>
        ///   This random number generator will generate our data points.
        /// </summary>
        private Random random;

        public MainWindow()
        {
            this.InitializeComponent();

            // crete a timer whose callback is in the same thread as the UI
            this.dTimer = new DispatcherTimer();

            // Have the callback run every millisecond
            this.dTimer.Interval = new TimeSpan(0, 0, 0, 0, 1);

            // set the timer's callback
            this.dTimer.Tick += this.dTimer_Tick;

            this.Loaded += this.MainWindow_Loaded;
        }

        private void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            this.xamChart1.Caption = new Caption { Text = "xamChart Rendering Speed Demo" };

            // begin the timer which will add data to the chart
            this.dTimer.Start();
        }

        private void dTimer_Tick(object sender, EventArgs e)
        {
            this.nMethodExecutionCount++;

            DateTime dtStart = DateTime.Now;

            this.xamChart1.Series[0].DataSource = null;

            this.xamChart1.Series[0].DataSource = this.PopulateData();

            this.xamChart1.Refresh();

            TimeSpan tsExecutionSpeed = DateTime.Now - dtStart;

            // estimate cycles per second at the current rate
            double dExecutionHertz = Math.Round((double)1000 / tsExecutionSpeed.Milliseconds, 2);

            string methodExecutionTimeReportingString =
                "Method Execution Time:\t{0} ticks\t{1} milliseconds\t{2}Hz (refreshes per second)";
            this.txtblkMethodExecutionTime.Text = string.Format(
                methodExecutionTimeReportingString, 
                tsExecutionSpeed.Ticks, 
                tsExecutionSpeed.Milliseconds, 
                dExecutionHertz);

            this.lstMethodExecutionTimes.Add(dExecutionHertz);

            string strMethodStatistics = "Method Execution Time:\tLow: {0}Hz\tAverage: {1}Hz\tHigh: {2}Hz";
            this.txtblkMethodExecutionStatistics.Text = string.Format(
                strMethodStatistics,
                Math.Round(this.lstMethodExecutionTimes.Min(), 2),
                Math.Round(this.lstMethodExecutionTimes.Average(), 2),
                Math.Round(this.lstMethodExecutionTimes.Max(), 2));

            string strMethodExecutionCount = "Method Execution Count:\t{0}";
            this.txtblkMethodExecutionCount.Text = string.Format(strMethodExecutionCount, this.nMethodExecutionCount);

        }

        private IEnumerable<Frequency> PopulateData()
        {
            this.random = new Random();

            for (int i = 0; i < 1000; i++)
            {
                Frequency frequency = new Frequency { Value = this.random.NextDouble() };

                yield return frequency;
            }
        }
    }
}